==> haskell-http-client-tls-0.3.6.4-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-KN3JTiWE2EI1kyisYRtf57
key:                  http-client-tls-0.3.6.4-KN3JTiWE2EI1kyisYRtf57
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  f50bebe97cbc8da2299c901069313b4e
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-KN3JTiWE2EI1kyisYRtf57
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9KyZd02Y5otGRG4cekIJFk containers-0.6.7
    crypton-1.0.3-LKmr8qwXaarCiLjwP8DUaY
    crypton-connection-0.4.4-4irtxig4UtYEvTUVCnwCkX
    data-default-0.7.1.2-434WfftxN7fJEVVCTZ9w4g exceptions-0.10.5
    http-client-0.7.19-9qUcwTVQqbvEShQpYcde6b
    http-types-0.12.4-9tb655S6p8NAIcFLCK3aeD
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-BeHm9PhAGW35QMcXomVSuT
    network-uri-2.6.4.2-FpQrzNLQnEFHV7gxKif8bC text-2.0.2
    tls-2.0.6-HKFXOGFMblLEtuEFCBgiDy transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.6.4-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-3SOG6pMBD126OroBvnbwcp
key:                  http-client-tls-0.3.6.4-3SOG6pMBD126OroBvnbwcp
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  c2ffff0dda4afa40ec5a8b1a65d724a1
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-3SOG6pMBD126OroBvnbwcp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-B227KtiOix4GTDgvxk3FBB containers-0.6.7
    crypton-1.0.3-4UnAyWN8beXD5nwa7txFxR
    crypton-connection-0.4.4-Ab8v787zCCYJ26NhXbMkEl
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM exceptions-0.10.5
    http-client-0.7.19-LRfftiQ6YWX88xW4fFXEK8
    http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    network-uri-2.6.4.2-8swvJWOy75N7pbfI8WzbN text-2.0.2
    tls-2.0.6-G1OfOfoVD5SESE7B79WJMM transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
